#
# spec file for package python-sphinx-autodoc-typehints
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-sphinx-autodoc-typehints
Version:        1.10.3
Release:        bp155.2.10
Summary:        Type hints (PEP 484) support for the Sphinx autodoc extension
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/agronholm/sphinx-autodoc-typehints
Source:         https://files.pythonhosted.org/packages/source/s/sphinx-autodoc-typehints/sphinx-autodoc-typehints-%{version}.tar.gz
# use object.inv which comes with python-doc; TODO more elegant solution
Patch0:         python-sphinx-autodoc-typehints-system-object.inv.patch
BuildRequires:  %{python_module setuptools >= 36.2.7}
BuildRequires:  %{python_module setuptools_scm >= 1.7.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Sphinx >= 1.7
Requires:       python-typing_extensions
BuildArch:      noarch
# SECTION tests
BuildRequires:  %{python_module Sphinx >= 1.7}
BuildRequires:  %{python_module doc}
BuildRequires:  %{python_module pathlib}
BuildRequires:  %{python_module sphobjinv}
BuildRequires:  %{python_module typing_extensions}
# /SECTION
%python_subpackages

%description
This is a Sphinx extension which allows to use Python 3 annotations for documenting acceptable argument types
and return value types of functions.

%prep
%setup -q -n sphinx-autodoc-typehints-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check

%files %{python_files}
%{python_sitelib}/*
%license LICENSE
%doc README.rst CHANGELOG.rst

%changelog
* Sun Feb 21 2021 Yuchen Lin <mlin+factory@suse.de>
- Disable test
* Fri Mar  6 2020 pgajdos@suse.com
- version update to 1.10.3
  * Fixed ``TypeError`` (or wrong rendered class name) when an annotation is a generic class that has
    a ``name`` property
  * Fixed inner classes missing their parent class name(s) when rendered
  * Fixed ``KeyError`` when encountering mocked annotations (``autodoc_mock_imports``)
  * Rewrote the annotation formatting logic (fixes Python 3.5.2 compatibility regressions and an
    ``AttributeError`` regression introduced in v1.9.0)
  * Fixed decorator classes not being processed as classes
  * Added support for typing_extensions_
  * Added the ``typehints_document_rtype`` option (PR by Simon-Martin Schröder)
  * Fixed metaclasses as annotations causing ``TypeError``
  * Fixed rendering of ``typing.Literal``
  * Fixed OSError when generating docs for SQLAlchemy mapped classes
  * Fixed unparametrized generic classes being rendered with their type parameters
    (e.g. ``Dict[~KT, ~VT]``)
- added patches
  fix use object.inv which comes with python-doc
  + python-sphinx-autodoc-typehints-system-object.inv.patch
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.8.0:
  * Fixed regression which caused TypeError or OSError when trying to set annotations due to PR #87
  * Fixed unintentional mangling of annotation type names
  * Added proper :py:data targets for NoReturn, ClassVar and Tuple
  * Added support for inline type comments (like (int, str) -> None) (PR by Bernát Gábor)
  * Use the native AST parser for type comment support on Python 3.8+
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7.0:
  * Fixed unwrapped local functions causing errors (PR by Kimiyuki Onaka)
  * Fixed AttributeError when documenting the __init__() method of a data class
  * Added support for type hint comments (PR by Markus Unterwaditzer)
  * Added flag for rendering classes with their fully qualified names (PR by Holly Becker)
- Remove merged patch sphinx21.patch
* Wed Jul  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix build with new sphinx:
  * sphinx21.patch
* Thu Jun  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop not really needed devel dependency
* Sat Mar 23 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Remove patch setup-tests.patch, we are using pytest now.
* Wed Mar 20 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- initial package for version 1.6.0
